@@ -10,6 +10,7 @@ RegisteredOption = namedtuple(
     "key defval doc validator"
 )
 age_down_to = 40
+age_floor = 50
 age_max = 99
 age_prop_size = 5
 comp_neg_temp_out = 'TEM'
@@ -31,6 +32,7 @@ comp_pos_put_etc_before = False
 comp_end = [comp_pos_npr_in]
 method_all = ['1dist', 'filler', 'prop']
 method = '1dist'
+method_use_second_pass = True
 pop_age = 'Age'
 pop_birth = 'BTH'
 pop_at_least = 1
@@ -109,6 +111,7 @@ def is_method(x):
 
     return None
 
+is_bool_mu2p = lambda x: is_bool(x, 'method_use.second_pass')
 is_containing_comp_end = lambda x: is_list_containing(x, 'comp.end', False)
 is_containing_netc = lambda x: is_list_containing(x, 'comp_neg.etc', False)
 is_containing_petc = lambda x: is_list_containing(x, 'comp_pos.etc', False)
@@ -116,6 +119,7 @@ is_etc_n_b4_inters = lambda x: is_bool(x, 'comp_neg.put_etc_before')
 is_etc_p_b4_inters = lambda x: is_bool(x, 'comp_pos.put_etc_before')
 is_int_age_max = lambda x: is_int(x, 'age.max')
 is_int_age_down_to = lambda x: is_int(x, 'age.down_to')
+is_int_age_floor = lambda x: is_int(x, 'age.floor')
 is_pos_age_prop_size = lambda x: is_nonnegative(x, 'age.prop_size', True)
 is_pos_pop_at_least = lambda x: is_nonnegative(x, 'pop.at_least')
 is_str_comp_neg_temp_out = lambda x: is_str(x, 'comp_neg.temp_out')
@@ -141,6 +145,7 @@ is_str_pop_start = lambda x: is_str(x, 'pop.start', False)
 _global_config = {
     'age': {
         'down_to': age_down_to,
+        'floor': age_floor,
         'max': age_max,
         'prop_size': age_prop_size
     },
@@ -168,6 +173,9 @@ _global_config = {
         'put_etc_before': comp_pos_put_etc_before
     },
     'method': method,
+    'method_use': {
+        'second_pass': method_use_second_pass
+    },
     'pop': {
         'age': pop_age,
         'birth': pop_birth,
@@ -183,13 +191,25 @@ _registered_options = {
         defval = age_down_to,
         doc =\
             "\n (int)\n    " +\
-            "A bottom level of the neighbouring ages for the " +\
-            "problematic age. Counter-adjustments are applied " +\
+            "A limit to which neighbouring ages are considered by the " +\
+            "estime2 package. Counter-adjustments are applied " +\
             "from the maximum neighbouring age and " +\
-            "all the way down to the maximum of -1 and " +\
-            "age of modification - age.down_to.",
+            "all the way down to min(age.floor, max(-1, " +\
+            "age of modification - age.down_to)).",
         validator = is_int_age_down_to
     ),
+    'age.floor': RegisteredOption(
+        key = 'age.floor',
+        defval = age_floor,
+        doc =\
+            "\n (int)\n    " +\
+            "A bottom level of old neighbouring ages of the " +\
+            "problematic age. The minimum counter-adjusted " +\
+            "neighbouring age will be either age.floor or " +\
+            "max(-1, age of modification - age.down_to), whichever " +\
+            "is smaller.",
+        validator = is_int_age_floor
+    ),
     'age.max': RegisteredOption(
         key = 'age.max',
         defval = age_max,
@@ -396,6 +416,20 @@ _registered_options = {
             "or 'prop'.",
         validator = is_method
     ),
+    'method_use.second_pass': RegisteredOption(
+        key = 'method_use.second_pass',
+        defval = method_use_second_pass,
+        doc =\
+            "\n (bool)\n    " +\
+            "(True by default) When using the '1dist' method, the " +\
+            "correction method applies the same method once again " +\
+            "to the same component in case where all the modification " +\
+            "value cannot be fixed in one shot. " +\
+            "Set it to True to use the second pass; set it to False " +\
+            'to fix the negative value "as much as possible" and ' +\
+            "nothing more.",
+        validator = is_bool_mu2p
+    ),
     'pop.age': RegisteredOption(
         key = "pop.age",
         defval = pop_age,
