@@ -1179,7 +1179,9 @@ class ProvPopTable(pd.DataFrame):
         '''
         Compute the actual amount of counter-adjustments to be applied to 
         the `comp` of `self` based on different `method`s. Specify `J` for
-        a faster computation.
+        a faster computation. Specifying the `method_use.second_pass` 
+        option will further determine how the amount of counter-adjustments
+        will be distributed when using the one-distribution method.
 
         Usage
         -----
@@ -1233,6 +1235,21 @@ class ProvPopTable(pd.DataFrame):
             possible. In case of tie proportions, take the oldest
             neighbouring-age record within the period. The process 
             continues until all the modification value is distributed.
+
+        This method tries to balance out the modification value in the 
+        problematic component as much as possible. In case where it is too 
+        big to be completely balanced out within the component, the method 
+        either: 
+        
+        a. stops the iteration (and move on to the next problematic
+            component to fix the remaining negative value), or;
+        b. runs the correction method once again in the same component
+
+        If the `method` argument/option is 'filler', 'prop', or '1dist'
+        with the `method_use.second_pass` (global) option being `False`, 
+        then the choice is always "a". If `method` is '1dist' and
+        `method_use.second_pass` is `True`, then the one-distribution is 
+        applied once again in the same problematic component.
         '''
 
         method = return_goption_if_None('method', method)
@@ -1256,6 +1273,9 @@ class ProvPopTable(pd.DataFrame):
 
         comp_K = "{0}_K".format(comp)
         result = []
+        max_correctables =\
+            df_comp_counter_adjust_reversed.iloc[:, -1].values.copy()
+
         if method == '1dist':
             for index, row in df_comp_counter_adjust_reversed.iterrows():
                 if row[comp_J] > 0 and to_modify_val_total != 0:
@@ -1263,6 +1283,16 @@ class ProvPopTable(pd.DataFrame):
                     to_modify_val_total -= 1
                 else:
                     result.append(0)
+            use_2nd_pass = get_option('method_use.second_pass')
+            if to_modify_val_total != 0 and use_2nd_pass:
+                # The first pass wasn't enough so that to_modify_val_total
+                # didn't come down to 0.
+                # Apply the second pass only if the option says so.
+                max_correctables -= np.array(result)
+                for i, item in enumerate(max_correctables):
+                    if item > 0 and to_modify_val_total != 0:
+                        result[i] += 1
+                        to_modify_val_total -= 1
         elif method == 'filler':
             for index, row in df_comp_counter_adjust_reversed.iterrows():
                 if row[comp_J] > 0 and to_modify_val_total != 0:
@@ -1292,8 +1322,6 @@ class ProvPopTable(pd.DataFrame):
             prop_size = get_option('age.prop_size')
             pop_end_for_prop =\
                 pop_end_to_compare_reversed.iloc[:, -1].values
-            max_correctables =\
-                df_comp_counter_adjust_reversed.iloc[:, -1].values
             pop_end_len = len(pop_end_for_prop)
             # Note: len(pop_end_for_prop) == len(max_correctables)
             for i in np.arange(pop_end_len, step = prop_size):
@@ -1434,6 +1462,7 @@ def calculate_ages_to_modify_and_counter(
     >>> # age.max == 99
     >>> age1 = Age(97)
     >>> age2 = Age('100+') # maximum age
+    >>> set_option('age.floor', 65)
     >>> result1 = calculate_ages_to_modify_and_counter(
     ...     age1, 
     ...     comp_in_comp_end = False
@@ -1470,16 +1499,39 @@ def calculate_ages_to_modify_and_counter(
     ...     'age.to_counter': [60, 99]
     ... }
     True
+    >>> set_option('age.floor', 50)
+    >>> result5 = calculate_ages_to_modify_and_counter(
+    ...     age1, 
+    ...     comp_in_comp_end = False
+    ... )
+    >>> result5 == {
+    ...     'age.to_modify': 96, 
+    ...     'age.to_counter': [50, 95]
+    ... }
+    True
+    >>> result6 = calculate_ages_to_modify_and_counter(
+    ...     age1, 
+    ...     comp_in_comp_end = True
+    ... )
+    >>> result6 == {
+    ...     'age.to_modify': 97, 
+    ...     'age.to_counter': [50, 96]
+    ... }
+    True
     '''
 
     age_down_to = get_option('age.down_to')
+    age_floor = get_option('age.floor')
     age_is_max = problematic_age.is_max()
     to_modify_age_str = str(problematic_age.get_showing_age())
     to_modify_age_int = int(to_modify_age_str) - 1
     if comp_in_comp_end:
         to_modify_age_int += 1
     to_counter_age_max = to_modify_age_int - 1
-    to_counter_age_min = max(to_modify_age_int - age_down_to, -1)
+    to_counter_age_min = min(
+        age_floor, 
+        max(-1, to_modify_age_int - age_down_to)
+    )
     to_modify_age_int_lst = None
     result = {}
     if age_is_max and not comp_in_comp_end:
@@ -1591,9 +1643,9 @@ def calculate_modifiable_in_comp(
     age_is_max = problematic_age.is_max()
     pop_end_query = None
     if age_is_max:
-        pop_end_query = "{0} > {1}".format(pop_age, get_option('age.max'))
+        pop_end_query = f"{pop_age} > {get_option('age.max')}"
     else:
-        pop_end_query = "{0} == {1}".format(pop_age, problematic_age)
+        pop_end_query = f"{pop_age} == {problematic_age}"
     df_pop_end_problematic = df_pop_end.query(pop_end_query)
     df_comp_modifiable = None
     if isinstance(to_modify_age, int):
@@ -1612,6 +1664,10 @@ def calculate_modifiable_in_comp(
     if isinstance(to_modify_age, int):
         modifiable_val_in_comp = df_comp_modifiable[comp].values[0]
         if comp_in_neg:
+            # `modifiable` also has to consider the sum of the
+            # counter-adjustable values in `min`, but it is not done here
+            # since it is deemed to be always greater than these two 
+            # numbers in the following min function.
             modifiable = min(
                 abs_modifiable_val_in_pop_end,
                 modifiable_val_in_comp
